from setuptools import setup

with open('README.md', 'r') as fh:
    long_description = fh.read()

setup(
    name='pyciactions',
    version='1.0.3',
    description='Declarative builder for Github Action Scripts',
    long_description=long_description,
    long_description_content_type='text/markdown',

    author='Julien Bongars',
    packages=['pyciactions'],
    install_requires=[
        "dataclasses==0.6",
        "PyYAML==6.0"
    ],
    url='https://github.com/JBongars/pyciactions',
)



import yaml
from datetime import datetime
from . import IWorkflow

def generate(workflow: IWorkflow, filename: str):
    workflow_dict = workflow.to_dict()
    yaml_string = yaml.dump(workflow_dict, sort_keys=False)

    print(f'echo -e "# Generated automatically on {datetime.now().isoformat()} using pyactions\n\n{yaml_string}" > {filename}')
